@@ -23,9 +23,9 @@ class.  For those wishing to override the braille generators, however,
 one can create a new instance and replace/extend the braille
 generators as they see fit."""
 
-__id__        = "$Id: braillegenerator.py,v 1.59 2006/10/12 00:33:47 wwalker Exp $"
-__version__   = "$Revision: 1.59 $"
-__date__      = "$Date: 2006/10/12 00:33:47 $"
+__id__        = "$Id: braillegenerator.py,v 1.62 2006/10/28 16:23:33 richb Exp $"
+__version__   = "$Revision: 1.62 $"
+__date__      = "$Date: 2006/10/28 16:23:33 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -193,9 +193,7 @@ class BrailleGenerator:
         Returns a string to be displayed.
         """
 
-        if (settings.brailleVerbosityLevel \
-            == settings.VERBOSITY_LEVEL_VERBOSE) \
-            and obj.state.count(atspi.Accessibility.STATE_SENSITIVE) == 0:
+        if obj.state.count(atspi.Accessibility.STATE_SENSITIVE) == 0:
             return _("grayed")
         else:
             return None
@@ -473,11 +471,15 @@ class BrailleGenerator:
         #
         if focusedRegionIndex >= len(regions):
             focusedRegionIndex = 0
+        if len(regions) == 0:
+            focusedRegion = None
+        else:
+            focusedRegion = regions[focusedRegionIndex]
 
         # [[[TODO: WDW - perhaps if a text area was created, we should
         # give focus to it.]]]
         #
-        return [regions, regions[focusedRegionIndex]]
+        return [regions, focusedRegion]
 
     def _getBrailleRegionsForDesktopIcon(self, obj):
         """Get the braille for a desktop icon.
@@ -1393,6 +1395,7 @@ class BrailleGenerator:
             # as bugzilla bug 319751.]]]
             #
             if (parent.role != rolenames.ROLE_FILLER) \
+                and (parent.role != rolenames.ROLE_SECTION) \
                 and (parent.role != rolenames.ROLE_SPLIT_PANE):
 
                 # Announce the label and text of the object in the hierarchy.
