@@ -19,9 +19,9 @@
 
 """Provides the FocusTrackingPresenter for Orca."""
 
-__id__        = "$Id: focus_tracking_presenter.py 1303 2006-08-10 11:53:22Z wwalker $"
-__version__   = "$Revision: 1303 $"
-__date__      = "$Date: 2006-08-10 07:53:22 -0400 (Thu, 10 Aug 2006) $"
+__id__        = "$Id: focus_tracking_presenter.py,v 1.90 2006/11/01 13:09:34 wwalker Exp $"
+__version__   = "$Revision: 1.90 $"
+__date__      = "$Date: 2006/11/01 13:09:34 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -37,6 +37,7 @@ import debug
 import input_event
 import orca_state
 import presentation_manager
+import rolenames
 import settings
 import speech
 import util
@@ -67,12 +68,13 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         #
         self.registry        = atspi.Registry()
         self._knownScripts   = {}
-        self._activeScript   = None
         self._eventQueue     = Queue.Queue(0)
         self._gidleId        = 0
         self._gidleLock      = threading.Lock()
         self.noFocusTimestamp = 0.0
 
+        orca_state.activeScript = None
+
         if settings.debugEventQueue:
             self._enqueueEventCount = 0
             self._dequeueEventCount = 0
@@ -306,9 +308,9 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         Arguments:
         - keyboardEvent: an instance of input_event.KeyboardEvent
         """
-        if self._activeScript:
+        if orca_state.activeScript:
             try:
-                self._activeScript.processKeyboardEvent(keyboardEvent)
+                orca_state.activeScript.processKeyboardEvent(keyboardEvent)
             except:
                 debug.printException(debug.LEVEL_WARNING)
                 debug.printStack(debug.LEVEL_WARNING)
@@ -319,9 +321,9 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         Arguments:
         - brailleEvent: an instance of input_event.BrailleEvent
         """
-        if self._activeScript:
+        if orca_state.activeScript:
             try:
-                self._activeScript.processBrailleEvent(brailleEvent)
+                orca_state.activeScript.processBrailleEvent(brailleEvent)
             except:
                 debug.printException(debug.LEVEL_WARNING)
                 debug.printStack(debug.LEVEL_WARNING)
@@ -335,6 +337,21 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
 
         debug.printObjectEvent(debug.LEVEL_FINEST, event)
 
+        # [[[TODO: WDW - HACK to prevent gnome-panel from killing
+        # itself.  It seems to do so after it issues some tool tip
+        # events and Orca attempts to process them.  We're not really
+        # doing anything with tool tips right now, so we just ignore
+        # them.  Note that this is just a bandaid to the problem.  We
+        # should do something better.  Please refer to bug 368626
+        # http://bugzilla.gnome.org/show_bug.cgi?id=368626 to follow
+        # this problem.]]]
+        #
+        try:
+            if event.source.role == rolenames.ROLE_TOOL_TIP:
+                return
+        except:
+            pass
+        
         # Reclaim (delete) any scripts when desktop children go away.
         # The idea here is that a desktop child is an app. We also
         # generally do not like object:children-changed:remove events,
@@ -398,18 +415,32 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         oldLocusOfFocus = orca_state.locusOfFocus
         while retryCount <= settings.commFailureAttemptLimit:
             try:
-                if event.type == "window:activate":
-                    # We'll let someone else decide if it's important
-                    # to stop speech or not.
-                    #speech.stop()
-                    self._activeScript = self._getScript(event.source.app)
-                    debug.println(debug.LEVEL_FINE, "ACTIVE SCRIPT: " \
-                                  + self._activeScript.name)
-                s = self._getScript(event.source.app)
-                s.processObjectEvent(event)
-                if retryCount:
-                    debug.println(debug.LEVEL_WARNING,
-                                  "  SUCCEEDED AFTER %d TRIES" % retryCount)
+                if not event.source.state.count( \
+                                      atspi.Accessibility.STATE_ICONIFIED):
+
+                    # [[[TODO: WDW - HACK we look for frame that get
+                    # focus: as a means to detect active scripts
+                    # because yelp does this.  Actually, yelp is a bit
+                    # odd in that it calls itself 'yelp' then changes
+                    # its application name and id to the Gecko toolkit
+                    # in use, and then issues a focus: event on the
+                    # main window, which is a frame.]]]
+                    #
+                    if (event.type == "window:activate") \
+                       or ((event.type == "focus:") \
+                           and (event.source.role == rolenames.ROLE_FRAME)):
+                        # We'll let someone else decide if it's important
+                        # to stop speech or not.
+                        #speech.stop()
+                        orca_state.activeScript = \
+                            self._getScript(event.source.app)
+                        debug.println(debug.LEVEL_FINE, "ACTIVE SCRIPT: " \
+                                      + orca_state.activeScript.name)
+                    s = self._getScript(event.source.app)
+                    s.processObjectEvent(event)
+                    if retryCount:
+                        debug.println(debug.LEVEL_WARNING,
+                                      "  SUCCEEDED AFTER %d TRIES" % retryCount)
                 break
             except CORBA.COMM_FAILURE:
                 debug.printException(debug.LEVEL_WARNING)
@@ -626,7 +657,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
             # some reason if done inside an acquire/release block for a
             # lock.  So...we do it here.]]]
             #
-            noFocus = (not self._activeScript) \
+            noFocus = (not orca_state.activeScript) \
                       or ((not orca_state.locusOfFocus) \
                           and (self.noFocusTimestamp \
                                != orca_state.noFocusTimestamp))
@@ -674,8 +705,8 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         Returns True if the event should be consumed.
         """
 
-        if self._activeScript \
-           and self._activeScript.consumesKeyboardEvent(keyboardEvent):
+        if orca_state.activeScript \
+           and orca_state.activeScript.consumesKeyboardEvent(keyboardEvent):
             self._enqueueEvent(keyboardEvent)
             return True
         else:
@@ -690,8 +721,8 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         Returns True if the command was consumed; otherwise False
         """
 
-        if self._activeScript \
-           and self._activeScript.consumesBrailleEvent(brailleEvent):
+        if orca_state.activeScript \
+           and orca_state.activeScript.consumesBrailleEvent(brailleEvent):
             self._enqueueEvent(brailleEvent)
             return True
         else:
@@ -706,10 +737,10 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         - newLocusOfFocus: Accessible that is the new locus of focus
         """
 
-        if self._activeScript:
-            self._activeScript.locusOfFocusChanged(event,
-                                                   oldLocusOfFocus,
-                                                   newLocusOfFocus)
+        if orca_state.activeScript:
+            orca_state.activeScript.locusOfFocusChanged(event,
+                                                        oldLocusOfFocus,
+                                                        newLocusOfFocus)
 
     def visualAppearanceChanged(self, event, obj):
         """Called when the visual appearance of an object changes.
@@ -725,8 +756,8 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         - obj: the Accessible whose visual appearance changed.
         """
 
-        if self._activeScript:
-            self._activeScript.visualAppearanceChanged(event, obj)
+        if orca_state.activeScript:
+            orca_state.activeScript.visualAppearanceChanged(event, obj)
 
     def activate(self):
         """Called when this presentation manager is activated."""
@@ -736,7 +767,8 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         self._listenerCounts = {}
         self._knownScripts   = {}
         self._defaultScript  = None
-        self._activeScript   = self._getScript(None)
+
+        orca_state.activeScript = self._getScript(None)
 
         self._registerEventListener("window:activate")
         self._registerEventListener("window:deactivate")
@@ -764,4 +796,5 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         self._listenerCounts = {}
         self._knownScripts   = {}
         self._defaultScript  = None
-        self._activeScript   = None
+
+        orca_state.activeScript = None
