@@ -21,9 +21,9 @@
 """Provides a methods that converts the role name of an Accessible
 object into localized strings for speech and braille."""
 
-__id__        = "$Id: rolenames.py,v 1.27 2006/10/12 18:13:03 wwalker Exp $"
-__version__   = "$Revision: 1.27 $"
-__date__      = "$Date: 2006/10/12 18:13:03 $"
+__id__        = "$Id: rolenames.py,v 1.29 2006/11/01 22:55:51 wwalker Exp $"
+__version__   = "$Revision: 1.29 $"
+__date__      = "$Date: 2006/11/01 22:55:51 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -63,6 +63,7 @@ ROLE_ENTRY               = "entry"
 ROLE_FILE_CHOOSER        = "file chooser"
 ROLE_FILLER              = "filler"
 ROLE_FONT_CHOOSER        = "fontchooser"
+ROLE_FORM                = "form"
 ROLE_FRAME               = "frame"
 ROLE_GLASS_PANE          = "glass pane"
 ROLE_HEADING             = "heading"
@@ -94,6 +95,7 @@ ROLE_ROOT_PANE           = "root pane"
 ROLE_ROW_HEADER          = "row header"
 ROLE_SCROLL_BAR          = "scroll bar"
 ROLE_SCROLL_PANE         = "scroll pane"
+ROLE_SECTION             = "section"
 ROLE_SEPARATOR           = "separator"
 ROLE_SLIDER              = "slider"
 ROLE_SPLIT_PANE          = "split pane"
@@ -263,6 +265,11 @@ rolenames[ROLE_FONT_CHOOSER] = Rolename(ROLE_FONT_CHOOSER,
                                         _("FontChooser"),
                                         _("font chooser"))
 
+rolenames[ROLE_FORM] = Rolename(ROLE_FORM,
+                                _("form"),
+                                _("Form"),
+                                _("form"))
+
 rolenames[ROLE_FRAME] = Rolename(ROLE_FRAME,
                                  _("frm"),
                                  _("Frame"),
@@ -274,9 +281,9 @@ rolenames[ROLE_GLASS_PANE] = Rolename(ROLE_GLASS_PANE,
                                       _("glass pane"))
 
 rolenames[ROLE_HEADING] = Rolename(ROLE_HEADING,
-                                   _("heading"),
+                                   _("hdng"),
                                    _("Heading"),
-                                   _("hdng"))
+                                   _("heading"))
 
 rolenames[ROLE_HTML_CONTAINER] = Rolename(ROLE_HTML_CONTAINER,
                                           _("html"),
@@ -308,6 +315,11 @@ rolenames[ROLE_LAYERED_PANE] = Rolename(ROLE_LAYERED_PANE,
                                         _("LayeredPane"),
                                         _("layered pane"))
 
+rolenames[ROLE_LINK] = Rolename(ROLE_LINK,
+                                _("lnk"),
+                                _("Link"),
+                                _("link"))
+
 rolenames[ROLE_LIST] = Rolename(ROLE_LIST,
                                 _("lst"),
                                 _("List"),
@@ -408,6 +420,11 @@ rolenames[ROLE_SCROLL_PANE] = Rolename(ROLE_SCROLL_PANE,
                                        _("ScrollPane"),
                                        _("scroll pane"))
 
+rolenames[ROLE_SECTION] = Rolename(ROLE_SECTION,
+                                   _("sctn"),
+                                   _("Section"),
+                                   _("section"))
+
 rolenames[ROLE_SEPARATOR] = Rolename(ROLE_SEPARATOR,
                                      _("seprtr"),
                                      _("Separator"),
