@@ -19,9 +19,9 @@
 
 """Custom script for Evolution."""
 
-__id__        = "$Id: Evolution.py,v 1.67 2006/09/29 17:02:23 wwalker Exp $"
-__version__   = "$Revision: 1.67 $"
-__date__      = "$Date: 2006/09/29 17:02:23 $"
+__id__        = "$Id: Evolution.py,v 1.70 2006/11/01 17:13:37 richb Exp $"
+__version__   = "$Revision: 1.70 $"
+__date__      = "$Date: 2006/11/01 17:13:37 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -29,6 +29,7 @@ import orca.debug as debug
 import orca.default as default
 import orca.atspi as atspi
 import orca.input_event as input_event
+import orca.keybindings as keybindings
 import orca.rolenames as rolenames
 import orca.braille as braille
 import orca.orca_state as orca_state
@@ -53,12 +54,12 @@ class Script(default.Script):
         - app: the application to create a script for.
         """
 
-        default.Script.__init__(self, app)
-
         # Set the debug level for all the methods in this script.
         #
         self.debugLevel = debug.LEVEL_FINEST
 
+        default.Script.__init__(self, app)
+
         # This will be used to cache a handle to the message area in the
         # Mail compose window.
 
@@ -77,6 +78,10 @@ class Script(default.Script):
         self.lastMessageColumn = -1
         self.lastMessageRow = -1
 
+        # By default, don't present if Evolution is not the active application.
+        #
+        self.presentIfInactive = False
+
         # Evolution defines new custom roles. We need to make them known
         # to Orca for Speech and Braille output.
 
@@ -107,6 +112,48 @@ class Script(default.Script):
                 Script.sayAll,
                 _("Speaks entire document."))
 
+        self.inputEventHandlers["toggleReadMailHandler"] = \
+            input_event.InputEventHandler(
+                Script.toggleReadMail,
+                _("Toggle whether we present new mail if we not not the active script."))
+
+    def getKeyBindings(self):
+        """Defines the new key binding for this script. Setup the default
+        key bindings, then add one in for toggling whether we present new
+        mail if we not not the active script.
+
+        Returns an instance of keybindings.KeyBindings.
+        """
+
+        debug.println(self.debugLevel, "Evolution.getKeyBindings.")
+
+        keyBindings = default.Script.getKeyBindings(self)
+
+        keyBindings.add(
+            keybindings.KeyBinding(
+                "n",
+                1 << settings.MODIFIER_ORCA,
+                1 << settings.MODIFIER_ORCA,
+                self.inputEventHandlers["toggleReadMailHandler"]))
+        return keyBindings
+
+    def toggleReadMail(self, inputEvent):
+        """ Toggle whether we present new mail if we not not the active script.+
+        Arguments:
+        - inputEvent: if not None, the input event that caused this action.
+        """
+
+        debug.println(self.debugLevel, "Evolution.toggleReadMail.")
+
+        line = _("present new mail if this script is not active.")
+        self.presentIfInactive = not self.presentIfInactive
+        if not self.presentIfInactive:
+            line = _("do not present new mail if this script is not active.")
+
+        speech.speak(line)
+
+        return True
+
     def speakSetupAssistantLabel(self, label):
         """Perform a variety of tests on this Setup Assistant label to see
         if we want to speak it.
@@ -497,6 +544,9 @@ class Script(default.Script):
                                 break
 
                     if toRead:
+                        obj = parent.table.getColumnHeader(i)
+                        header = atspi.Accessible.makeAccessible(obj)
+
                         # Speak/braille the column header for this table cell
                         # if it has focus (unless it's a checkbox).
                         if not checkbox and verbose:
@@ -505,8 +555,6 @@ class Script(default.Script):
                             settings.speechVerbosityLevel = \
                                 settings.VERBOSITY_LEVEL_BRIEF
 
-                            obj = parent.table.getColumnHeader(i)
-                            header = atspi.Accessible.makeAccessible(obj)
                             utterances = speechGen.getSpeech(header, False)
                             [headerRegions, focusedRegion] = \
                                          brailleGen.getBrailleRegions(header)
@@ -518,7 +566,12 @@ class Script(default.Script):
                             if speakAll or (column == i):
                                 speech.speakUtterances(utterances)
 
-                        # Speak/braille the table cell.
+                        # Speak/braille the table cell. 
+                        #
+                        # If this cell has a column header of "Status",
+                        # then speak/braille "read".
+                        # If this cell has a column header of "Attachment",
+                        # then speak/braille "attachment".
                         #
                         if verbose:
                             settings.brailleVerbosityLevel = \
@@ -531,8 +584,20 @@ class Script(default.Script):
                         utterances = speechGen.getSpeech(cell, False)
                         [cellRegions, focusedRegion] = \
                                            brailleGen.getBrailleRegions(cell)
-                        brailleRegions.extend(cellRegions)
-                        brailleRegions.append(braille.Region(" "))
+
+                        if header.name == _("Status"):
+                            text = _("Read")
+                            utterances = [ text ]
+                            brailleRegions.append(braille.Region(text))
+                            brailleRegions.append(braille.Region(" "))
+                        elif header.name == _("Attachment"):
+                            text = header.name
+                            utterances = [ text ]
+                            brailleRegions.append(braille.Region(text))
+                            brailleRegions.append(braille.Region(" "))
+                        else:
+                            brailleRegions.extend(cellRegions)
+                            brailleRegions.append(braille.Region(" "))
 
                         # If the current focus is on a checkbox then we won't
                         # have set braille line focus to its header above, so
