@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005 Sun Microsystems Inc.
+# Copyright 2005-2006 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -24,12 +24,15 @@ machine to speak.  Each speech server provides a set of known
 voices (identified by name) which can be combined with various
 attributes to create aural style sheets."""
 
-__id__        = "$Id: speechserver.py,v 1.18 2006/06/10 00:54:47 wwalker Exp $"
-__version__   = "$Revision: 1.18 $"
-__date__      = "$Date: 2006/06/10 00:54:47 $"
+__id__        = "$Id: speechserver.py,v 1.20 2006/10/13 23:39:04 wwalker Exp $"
+__version__   = "$Revision: 1.20 $"
+__date__      = "$Date: 2006/10/13 23:39:04 $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
+import logging
+log = logging.getLogger("speech")
+
 import debug
 
 class VoiceFamily(dict):
@@ -221,6 +224,7 @@ class SpeechServer:
         for [context, acss] in utteranceIterator:
             debug.println(debug.LEVEL_INFO,
                           "SPEECH OUTPUT: '" + context.utterance + "'")
+            log.info("'%s'" % context.utterance)
             self.speak(context.utterance, acss)
 
     def increaseSpeechRate(self, step=5):
